@@ -72,15 +72,13 @@ class DelegatedUserManager {
                     can_manage_domains, can_manage_sites, can_manage_databases, 
                     can_manage_email, can_manage_files, can_manage_backups,
                     can_view_terminal, can_manage_wordpress,
-                    allowed_domains, max_domains, max_databases, max_email_accounts,
-                    created_by
+                    allowed_domains, created_by
                 ) VALUES (
                     :username, :password_hash, :parent_username, :display_name, :email,
                     :can_manage_domains, :can_manage_sites, :can_manage_databases,
                     :can_manage_email, :can_manage_files, :can_manage_backups,
                     :can_view_terminal, :can_manage_wordpress,
-                    :allowed_domains, :max_domains, :max_databases, :max_email_accounts,
-                    :created_by
+                    :allowed_domains, :created_by
                 )
             ");
             
@@ -100,9 +98,6 @@ class DelegatedUserManager {
                 ':can_view_terminal' => ($data['can_view_terminal'] ?? false) ? 1 : 0,
                 ':can_manage_wordpress' => ($data['can_manage_wordpress'] ?? false) ? 1 : 0,
                 ':allowed_domains' => isset($data['allowed_domains']) ? json_encode($data['allowed_domains']) : null,
-                ':max_domains' => $data['max_domains'] ?? null,
-                ':max_databases' => $data['max_databases'] ?? null,
-                ':max_email_accounts' => $data['max_email_accounts'] ?? null,
                 ':created_by' => $created_by
             ]);
             
@@ -291,8 +286,7 @@ class DelegatedUserManager {
                        can_manage_domains, can_manage_sites, can_manage_databases,
                        can_manage_email, can_manage_files, can_manage_backups,
                        can_view_terminal, can_manage_wordpress,
-                       allowed_domains, max_domains, max_databases, max_email_accounts,
-                       is_active, last_login, created_at
+                       allowed_domains, is_active, last_login, created_at
                 FROM delegated_users 
                 WHERE {$where_clause}
                 ORDER BY created_at DESC
@@ -325,8 +319,7 @@ class DelegatedUserManager {
                        can_manage_domains, can_manage_sites, can_manage_databases,
                        can_manage_email, can_manage_files, can_manage_backups,
                        can_view_terminal, can_manage_wordpress,
-                       allowed_domains, max_domains, max_databases, max_email_accounts,
-                       is_active, last_login, created_at
+                       allowed_domains, is_active, last_login, created_at
                 FROM delegated_users 
                 WHERE {$where_clause}
                 ORDER BY parent_username, created_at DESC
@@ -368,8 +361,7 @@ class DelegatedUserManager {
                 'display_name', 'email', 'can_manage_domains', 'can_manage_sites',
                 'can_manage_databases', 'can_manage_email', 'can_manage_files',
                 'can_manage_backups', 'can_view_terminal', 'can_manage_wordpress',
-                'allowed_domains', 'max_domains', 'max_databases', 'max_email_accounts',
-                'is_active'
+                'allowed_domains', 'is_active'
             ];
             
             $update_fields = [];
