@@ -32,9 +32,6 @@ if ($_SERVER['REQUEST_METHOD'] === 'POST' && !$is_delegated_user) {
                     'can_manage_backups' => isset($_POST['can_manage_backups']),
                     'can_view_terminal' => isset($_POST['can_view_terminal']),
                     'can_manage_wordpress' => isset($_POST['can_manage_wordpress']),
-                    'max_domains' => !empty($_POST['max_domains']) ? intval($_POST['max_domains']) : null,
-                    'max_databases' => !empty($_POST['max_databases']) ? intval($_POST['max_databases']) : null,
-                    'max_email_accounts' => !empty($_POST['max_email_accounts']) ? intval($_POST['max_email_accounts']) : null,
                 ];
                 
                 // Handle allowed domains
@@ -68,9 +65,6 @@ if ($_SERVER['REQUEST_METHOD'] === 'POST' && !$is_delegated_user) {
                     'can_view_terminal' => isset($_POST['can_view_terminal']),
                     'can_manage_wordpress' => isset($_POST['can_manage_wordpress']),
                     'is_active' => isset($_POST['is_active']),
-                    'max_domains' => !empty($_POST['max_domains']) ? intval($_POST['max_domains']) : null,
-                    'max_databases' => !empty($_POST['max_databases']) ? intval($_POST['max_databases']) : null,
-                    'max_email_accounts' => !empty($_POST['max_email_accounts']) ? intval($_POST['max_email_accounts']) : null,
                 ];
                 
                 // Handle allowed domains
@@ -229,8 +223,9 @@ if ($is_root) {
                 </p>
                 <?php else: ?>
                 <p class="card-text">
-                    Delegated users are sub-accounts that can access specific features within a parent user's account.
-                    They provide a way to grant limited access to team members or clients without sharing the main account credentials.
+                    Delegated users are team members who can access specific features within your account.
+                    Grant role-based permissions to collaborators without sharing your main account credentials.
+                    Team members work with your existing resources based on their assigned permissions.
                 </p>
                 <?php endif; ?>
                 
@@ -259,7 +254,7 @@ if ($is_root) {
     <div class="col-12">
         <div class="card">
             <div class="card-header">
-                <h5 class="card-title mb-0">Create New Delegated User</h5>
+                <h5 class="card-title mb-0">Add Team Member</h5>
             </div>
             <div class="card-body">
                 <form method="POST" action="">
@@ -350,42 +345,18 @@ if ($is_root) {
                             </div>
                             
                             <div class="row">
-                                <div class="col-md-6">
+                                <div class="col-md-12">
                                     <div class="mb-3">
-                                        <label for="max_domains" class="form-label">Max Domains</label>
-                                        <input type="number" class="form-control" id="max_domains" name="max_domains" min="0">
-                                        <div class="form-text">Leave empty for unlimited</div>
-                                    </div>
-                                </div>
-                                <div class="col-md-6">
-                                    <div class="mb-3">
-                                        <label for="max_databases" class="form-label">Max Databases</label>
-                                        <input type="number" class="form-control" id="max_databases" name="max_databases" min="0">
-                                        <div class="form-text">Leave empty for unlimited</div>
-                                    </div>
-                                </div>
-                            </div>
-                            
-                            <div class="row">
-                                <div class="col-md-6">
-                                    <div class="mb-3">
-                                        <label for="max_email_accounts" class="form-label">Max Email Accounts</label>
-                                        <input type="number" class="form-control" id="max_email_accounts" name="max_email_accounts" min="0">
-                                        <div class="form-text">Leave empty for unlimited</div>
-                                    </div>
-                                </div>
-                                <div class="col-md-6">
-                                    <div class="mb-3">
-                                        <label for="allowed_domains" class="form-label">Allowed Domains</label>
-                                        <input type="text" class="form-control" id="allowed_domains" name="allowed_domains">
-                                        <div class="form-text">Comma-separated list, empty for all</div>
+                                        <label for="allowed_domains" class="form-label">Specific Domain Access (Optional)</label>
+                                        <input type="text" class="form-control" id="allowed_domains" name="allowed_domains" placeholder="example.com, subdomain.example.com">
+                                        <div class="form-text">Restrict access to specific domains only. Leave empty to allow access to all parent account domains based on permissions.</div>
                                     </div>
                                 </div>
                             </div>
                         </div>
                     </div>
                     
-                    <button type="submit" class="btn btn-primary">Create Delegated User</button>
+                    <button type="submit" class="btn btn-primary">Add Team Member</button>
                 </form>
             </div>
         </div>
@@ -582,9 +553,9 @@ if ($is_root) {
                     </div>
                     
                     <div class="mb-3">
-                        <label for="edit_allowed_domains" class="form-label">Allowed Domains</label>
-                        <input type="text" class="form-control" id="edit_allowed_domains" name="allowed_domains">
-                        <div class="form-text">Comma-separated list, empty for all</div>
+                        <label for="edit_allowed_domains" class="form-label">Specific Domain Access (Optional)</label>
+                        <input type="text" class="form-control" id="edit_allowed_domains" name="allowed_domains" placeholder="example.com, subdomain.example.com">
+                        <div class="form-text">Restrict access to specific domains only. Leave empty to allow access to all parent account domains based on permissions.</div>
                     </div>
                 </div>
                 <div class="modal-footer">
@@ -645,11 +616,6 @@ function editUser(userId) {
     document.getElementById('edit_can_view_terminal').checked = user.can_view_terminal == 1;
     document.getElementById('edit_can_manage_wordpress').checked = user.can_manage_wordpress == 1;
     
-    // Set limits
-    document.getElementById('edit_max_domains').value = user.max_domains || '';
-    document.getElementById('edit_max_databases').value = user.max_databases || '';
-    document.getElementById('edit_max_email_accounts').value = user.max_email_accounts || '';
-    
     // Set allowed domains
     if (user.allowed_domains) {
         const domains = JSON.parse(user.allowed_domains);
